==> pmml-model-1.4.4-sources.jar: org/dmg/pmml/support_vector_machine/PolynomialKernel.java <==

package org.dmg.pmml.support_vector_machine;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.PMMLObject;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Property;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
public class PolynomialKernel
    extends Kernel
    implements HasExtensions<PolynomialKernel>
{

    @XmlAttribute(name = "description")
    private String description;
    @XmlAttribute(name = "gamma")
    private Double gamma;
    @XmlAttribute(name = "coef0")
    private Double coef0;
    @XmlAttribute(name = "degree")
    private Double degree;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    private final static Double DEFAULT_GAMMA = 1.0D;
    private final static Double DEFAULT_COEF0 = 1.0D;
    private final static Double DEFAULT_DEGREE = 1.0D;
    private final static long serialVersionUID = 67305483L;

    public String getDescription() {
        return description;
    }

    public PolynomialKernel setDescription(
        @Property("description")
        String description) {
        this.description = description;
        return this;
    }

    public Double getGamma() {
        if (gamma == null) {
            return DEFAULT_GAMMA;
        } else {
            return gamma;
        }
    }

    public PolynomialKernel setGamma(
        @Property("gamma")
        Double gamma) {
        this.gamma = gamma;
        return this;
    }

    public Double getCoef0() {
        if (coef0 == null) {
            return DEFAULT_COEF0;
        } else {
            return coef0;
        }
    }

    public PolynomialKernel setCoef0(
        @Property("coef0")
        Double coef0) {
        this.coef0 = coef0;
        return this;
    }

    public Double getDegree() {
        if (degree == null) {
            return DEFAULT_DEGREE;
        } else {
            return degree;
        }
    }

    public PolynomialKernel setDegree(
        @Property("degree")
        Double degree) {
        this.degree = degree;
        return this;
    }

    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public PolynomialKernel addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.4.9-sources.jar: org/dmg/pmml/support_vector_machine/PolynomialKernel.java <==

package org.dmg.pmml.support_vector_machine;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.PMMLObject;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Property;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "description",
    "gamma",
    "coef0",
    "degree",
    "extensions"
})
public class PolynomialKernel
    extends Kernel
    implements HasExtensions<PolynomialKernel>
{

    @XmlAttribute(name = "description")
    @JsonProperty("description")
    private String description;
    @XmlAttribute(name = "gamma")
    @JsonProperty("gamma")
    private Double gamma;
    @XmlAttribute(name = "coef0")
    @JsonProperty("coef0")
    private Double coef0;
    @XmlAttribute(name = "degree")
    @JsonProperty("degree")
    private Double degree;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static Double DEFAULT_GAMMA = 1.0D;
    private final static Double DEFAULT_COEF0 = 1.0D;
    private final static Double DEFAULT_DEGREE = 1.0D;
    private final static long serialVersionUID = 67305486L;

    public String getDescription() {
        return description;
    }

    public PolynomialKernel setDescription(
        @Property("description")
        String description) {
        this.description = description;
        return this;
    }

    public Double getGamma() {
        if (gamma == null) {
            return DEFAULT_GAMMA;
        } else {
            return gamma;
        }
    }

    public PolynomialKernel setGamma(
        @Property("gamma")
        Double gamma) {
        this.gamma = gamma;
        return this;
    }

    public Double getCoef0() {
        if (coef0 == null) {
            return DEFAULT_COEF0;
        } else {
            return coef0;
        }
    }

    public PolynomialKernel setCoef0(
        @Property("coef0")
        Double coef0) {
        this.coef0 = coef0;
        return this;
    }

    public Double getDegree() {
        if (degree == null) {
            return DEFAULT_DEGREE;
        } else {
            return degree;
        }
    }

    public PolynomialKernel setDegree(
        @Property("degree")
        Double degree) {
        this.degree = degree;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public PolynomialKernel addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
